=======
editors
=======


.. automodule:: camelot.view.controls.editors
   :members:

.. toctree::

   abstractmanytooneeditor.rst
   booleditor.rst
   charteditor.rst
   choiceseditor.rst
   codeeditor.rst
   coloredfloateditor.rst
   coloreditor.rst
   customeditor.rst
   dateeditor.rst
   datetimeeditor.rst
   embeddedmany2oneeditor.rst
   fileeditor.rst
   floateditor.rst
   imageeditor.rst
   integereditor.rst
   labeleditor.rst
   languageeditor.rst
   localfileeditor.rst
   many2oneeditor.rst
   manytomanyeditor.rst
   monthseditor.rst
   noteeditor.rst
   one2manyeditor.rst
   onetomanychoiceseditor.rst
   richtexteditor.rst
   smileyeditor.rst
   stareditor.rst
   textediteditor.rst
   textlineeditor.rst
   timeeditor.rst
   virtualaddresseditor.rst
   wideeditor.rst
